@@ -44,11 +44,8 @@ class simple_discord_bot:
         command_list.append(command_to_add)
 
     def set_token(self, token):
-        try:
-            client.run(token)
-        except Exception as login_error:
-            print(login_error)
-
+        global client
+        client.run(token)
 
 @client.event
 async def on_ready():
